@@ -1,21 +1,18 @@
 // Copyright 2018-2022 System76 <info@system76.com>
-// SPDX-License-Identifier: MIT
+// SPDX-License-Identifier: MIT OR Apache-2.0
 
-extern crate clap;
-extern crate sys_mount;
+use clap::{Arg, Command};
+use std::process::ExitCode;
+use sys_mount::{Mount, SupportedFilesystems};
 
-use clap::{App, Arg};
-use std::process::exit;
-use sys_mount::{Mount, MountFlags, SupportedFilesystems};
-
-fn main() {
-    let matches = App::new("mount")
-        .arg(Arg::with_name("source").required(true))
-        .arg(Arg::with_name("directory").required(true))
+fn main() -> ExitCode {
+    let matches = Command::new("mount")
+        .arg(Arg::new("source").required(true))
+        .arg(Arg::new("directory").required(true))
         .get_matches();
 
-    let src = matches.value_of("source").unwrap();
-    let dir = matches.value_of("directory").unwrap();
+    let src = matches.get_one::<String>("source").unwrap();
+    let dir = matches.get_one::<String>("directory").unwrap();
 
     // Fetch a listed of supported file systems on this system. This will be used
     // as the fstype to `Mount::new`, as the `Auto` mount parameter.
@@ -23,19 +20,20 @@ fn main() {
         Ok(supported) => supported,
         Err(why) => {
             eprintln!("failed to get supported file systems: {}", why);
-            exit(1);
+            return ExitCode::FAILURE;
         }
     };
 
     // The source block will be mounted to the target directory, and the fstype is likely
     // one of the supported file systems.
-    match Mount::new(src, dir, &supported, MountFlags::empty(), None) {
+    match Mount::builder().fstype(&supported).mount(src, dir) {
         Ok(mount) => {
             println!("mounted {} ({}) to {}", src, mount.get_fstype(), dir);
+            ExitCode::SUCCESS
         }
         Err(why) => {
             eprintln!("failed to mount {} to {}: {}", src, dir, why);
-            exit(1);
+            ExitCode::FAILURE
         }
     }
 }
